@@ -1,6 +1,6 @@
 .onAttach <-
 function (libname, pkgname){
    # echo output to screen
-   packageStartupMessage("## Syntax has been updated since v.1.2.0.")
+   packageStartupMessage("## Since v.1.3.0, *gsynth* is a wrapper of the *fect* package.")
    packageStartupMessage("## Comments and suggestions -> yiqingxu@stanford.edu.")
 }
